@@ -33,18 +33,23 @@ static const struct option pknock_mt_opts[] = {
 static void pknock_mt_help(void)
 {
 	printf("pknock match options:\n"
-		" --knockports port[,port,port,...]	"
-			"Matches destination port(s).\n"
-		" --time seconds\n"
+		"  --knockports port[,port[,port[,...]]]\n"
+			"\t\t\t\tMatches destination port(s).\n"
+		"  --time seconds		"
 			"Max allowed time between knocks.\n"
-		" --autoclose minutes\n"
+		"  --autoclose minutes		"
 			"Time after which to automatically close opened\n"
-			"\t\t\t\t\tport(s).\n"
-		" --strict				"
-			"Knocks sequence must be exact.\n"
-		" --name rule_name			"
+			"\t\t\t\tport(s).\n"
+		"  --name rule_name		"
 			"Rule name.\n"
-		" --checkip				"
+		"  --opensecret secret		"
+			"(UDP only) Secret to activate the rule.\n"
+		"  --closesecret secret		"
+			"(UDP only) Secret to deactivate the\n"
+			"\t\t\t\trule.\n"
+		"  --strict			"
+			"Knocks sequence must be exact.\n"
+		"  --checkip			"
 			"Matches if the source ip is in the list.\n"
 		);
 }
