@@ -150,6 +150,10 @@ static void xttarpit_reset(struct tcphdr *tcph, const struct tcphdr *oth)
 	tcph->ack_seq = oth->seq;
 }
 
+/**
+ * @tcph: newly-being-built transport header
+ * @oth:  original transport header
+ */
 static bool tarpit_generic(struct tcphdr *tcph, const struct tcphdr *oth,
     uint16_t payload, unsigned int mode)
 {
@@ -307,7 +311,10 @@ static void tarpit_tcp6(const struct xt_action_param *par,
 	int tcphoff;
 	const struct ipv6hdr *oip6h = ipv6_hdr(oldskb);
 	struct ipv6hdr *ip6h;
+	struct dst_entry *dst;
+	struct net *net;
 	const uint8_t tclass = 0;
+	struct flowi6 fl6;
 	uint8_t proto;
 	uint16_t payload;
 	__be16 frag_off;
@@ -337,8 +344,7 @@ static void tarpit_tcp6(const struct xt_action_param *par,
 	}
 
 	/* Check checksum. */
-	if (csum_ipv6_magic(&oip6h->saddr, &oip6h->daddr, otcplen, IPPROTO_TCP,
-	    skb_checksum(oldskb, tcphoff, otcplen, 0))) {
+	if (nf_ip6_checksum(oldskb, xt_hooknum(par), tcphoff, IPPROTO_TCP)) {
 		pr_debug("TCP checksum is invalid\n");
 		return;
 	}
@@ -370,12 +376,8 @@ static void tarpit_tcp6(const struct xt_action_param *par,
 	ip6h->daddr = oip6h->saddr;
 
 	/* Adjust IP TTL */
-	if (mode == XTTARPIT_HONEYPOT) {
-		ip6h->hop_limit = 128;
-	} else {
-		ip6h->hop_limit = ip6_dst_hoplimit(skb_dst(nskb));
-	}
-
+	ip6h->hop_limit = mode == XTTARPIT_HONEYPOT ? 128 :
+	                  ip6_dst_hoplimit(skb_dst(nskb));
 	tcph = (struct tcphdr *)(skb_network_header(nskb) +
 	       sizeof(struct ipv6hdr));
 
@@ -389,25 +391,51 @@ static void tarpit_tcp6(const struct xt_action_param *par,
 	((uint8_t *)tcph)[13] = 0;
 
 	payload = nskb->len - sizeof(struct ipv6hdr) - sizeof(struct tcphdr);
-	if (!tarpit_generic(&oth, tcph, payload, mode))
+	if (!tarpit_generic(tcph, &oth, payload, mode))
 		goto free_nskb;
 
 	ip6h->payload_len = htons(sizeof(struct tcphdr));
 	tcph->check = 0;
 
 	/* Adjust TCP checksum */
-	tcph->check = csum_ipv6_magic(&ipv6_hdr(nskb)->saddr,
-	              &ipv6_hdr(nskb)->daddr, sizeof(struct tcphdr),
-	              IPPROTO_TCP,
+	tcph->check = csum_ipv6_magic(&ip6h->saddr, &ip6h->daddr,
+	              sizeof(struct tcphdr), IPPROTO_TCP,
 	              csum_partial(tcph, sizeof(struct tcphdr), 0));
-	if (ip6_route_me_harder(par_net(par), nskb->sk, nskb))
+
+	net = par_net(par);
+	memset(&fl6, 0, sizeof(fl6));
+	fl6.flowi6_proto = IPPROTO_TCP;
+	fl6.saddr = ip6h->saddr;
+	fl6.daddr = ip6h->daddr;
+	fl6.fl6_sport = tcph->source;
+	fl6.fl6_dport = tcph->dest;
+	if (!skb_dst(nskb)) {
+		/* This is for when the target is used in PREROUTING or INGRESS (cf. nf_send_reset6) */
+		nf_ip6_route(net, &dst, flowi6_to_flowi(&fl6), false);
+		if (dst == NULL)
+			goto free_nskb;
+		skb_dst_set(nskb, dst);
+	}
+	fl6.flowi6_oif = l3mdev_master_ifindex(READ_ONCE(skb_dst(nskb)->dev));
+	fl6.flowi6_mark = IP6_REPLY_MARK(net, oldskb->mark);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 11, 0)
+	security_skb_classify_flow(nskb, flowi6_to_flowi_common(&fl6));
+#else
+	security_skb_classify_flow(nskb, flowi6_to_flowi(&fl6));
+#endif
+	dst = ip6_route_output(net, NULL, &fl6);
+	if (dst->error) {
+		dst_release(dst);
 		goto free_nskb;
-
+	}
+	dst = xfrm_lookup(net, dst, flowi6_to_flowi(&fl6), NULL, 0);
+	if (IS_ERR(dst))
+		goto free_nskb;
+	skb_dst_set(nskb, dst);
 	nskb->ip_summed = CHECKSUM_NONE;
-
+	nskb->mark = fl6.flowi6_mark;
 	nf_ct_attach(nskb, oldskb);
-	NF_HOOK(NFPROTO_IPV6, NF_INET_LOCAL_OUT, par_net(par), nskb->sk, nskb,
-	        NULL, skb_dst(nskb)->dev, dst_output);
+	ip6_local_out(net, nskb->sk, nskb);
 	return;
 
  free_nskb:
@@ -471,6 +499,11 @@ tarpit_tg6(struct sk_buff *skb, const struct xt_action_param *par)
 		pr_debug("type != PACKET_HOST");
 		return NF_DROP;
 	}
+	if ((!(ipv6_addr_type(&iph->saddr) & IPV6_ADDR_UNICAST)) ||
+	    (!(ipv6_addr_type(&iph->daddr) & IPV6_ADDR_UNICAST))) {
+		pr_debug("addr is not unicast.\n");
+		return NF_DROP;
+	}
 
 	/*
 	 * Our naive response construction does not deal with IP
@@ -481,11 +514,6 @@ tarpit_tg6(struct sk_buff *skb, const struct xt_action_param *par)
 	    &frag_off) != sizeof(struct ipv6hdr))
 		return NF_DROP;
 
-	if ((!(ipv6_addr_type(&iph->saddr) & IPV6_ADDR_UNICAST)) ||
-	    (!(ipv6_addr_type(&iph->daddr) & IPV6_ADDR_UNICAST))) {
-		pr_debug("addr is not unicast.\n");
-		return NF_DROP;
-	}
 	tarpit_tcp6(par, skb, info->variant);
 	return NF_DROP;
 }
